@@ -31,6 +31,10 @@ class TestConfig:
         self.run_only_some_tests = False
         self.only = set()
 
+        # Don't fail on out-of-tolerance stat failures
+        self.ignore_perf_increases = False
+        self.ignore_perf_decreases = False
+
         # Accept new output which differs from the sample?
         self.accept = False
         self.accept_platform = False
@@ -83,7 +87,7 @@ class TestConfig:
         self.wordsize = ''
 
         # Verbosity level
-        self.verbose = 3
+        self.verbose = 2
 
         # See Note [validate and testsuite speed] in toplevel Makefile.
         self.speed = 1
@@ -130,8 +134,16 @@ class TestConfig:
         # Do we have interpreter support?
         self.have_interp = False
 
-        # Do we have shared libraries?
-        self.have_shared_libs = False
+        # Does the platform support loading of dynamic shared libraries? e.g.
+        # some musl-based environments do not.
+        self.supports_dynamic_libs = True
+
+        # Does GHC support dynamic linking of Haskell objects (i.e. the dynamic
+        # way)?
+        self.supports_dynamic_hs = True
+
+        # Is the compiler dynamically linked?
+        self.ghc_dynamic = False
 
         # Do we have SMP support?
         self.have_smp = False
@@ -148,12 +160,12 @@ class TestConfig:
         # Are we testing an in-tree compiler?
         self.in_tree_compiler = True
 
-        # Is the compiler dynamically linked?
-        self.ghc_dynamic = False
-
         # Are we running in a ThreadSanitizer-instrumented build?
         self.have_thread_sanitizer = False
 
+        # Do symbols use leading underscores?
+        self.leading_underscore = False
+
         # the timeout program
         self.timeout_prog = ''
         self.timeout = 300
@@ -166,9 +178,12 @@ class TestConfig:
         # run.
         self.broken_tests = set() # type: Set[TestName]
 
-        # Baseline commit for performane metric comparisons.
+        # Baseline commit for performance metric comparisons.
         self.baseline_commit = None # type: Optional[GitRef]
 
+        # Additional package dbs to inspect for test dependencies.
+        self.test_package_db = [] # type: [PathToPackageDb]
+
         # Should we skip performance tests
         self.skip_perf_tests = False
 
@@ -195,6 +210,22 @@ class TestConfig:
         # I have no idea what this does
         self.package_conf_cache_file = None # type: Optional[Path]
 
+        # The extra hadrian dependencies we need for all configured tests
+        self.hadrian_deps = set() # type: Set[str]
+
+        # Are we only reporting hadrian dependencies?
+        self.only_report_hadrian_deps = False # type: bool
+
+
+    def validate(self) -> None:
+        """ Check the TestConfig for self-consistency """
+        def assert_implies(a: bool, b: bool):
+            if a:
+                assert(b)
+
+        assert_implies(self.supports_dynamic_hs, self.supports_dynamic_libs)
+        assert_implies(self.have_dynamic, self.supports_dynamic_hs)
+        assert_implies(self.ghc_dynamic, self.have_dynamic)
 
 global config
 config = TestConfig()
@@ -411,6 +442,12 @@ class TestOptions:
        # in temporary directory in /tmp? See Note [Running tests in /tmp].
        self.local = True
 
+       # Should we copy the files of symlink the files for the test?
+       self.copy_files = False
+
+       # The extra hadrian dependencies we need for this particular test
+       self.hadrian_deps = set() # type: Set[str]
+
 # The default set of options
 global default_testopts
 default_testopts = TestOptions()
