@@ -12,6 +12,7 @@ import GHC.Driver.Session
 import GHC.Utils.Error
 import GHC.Utils.Outputable as Outputable
 import GHC.Builtin.Types
+import GHC.Builtin.Uniques
 import GHC.Types.Literal
 import GHC
 import Control.Monad
@@ -73,7 +74,7 @@ exprs =
                           (mkLams [y] $ Var y)
                   ) $ mkLams [z] $ Var d `mkVarApps` [x]) $
         Case (go `mkLApps` [0, 0]) z intTy
-            [(DEFAULT, [], Var f `mkVarApps` [z,z])]
+            [Alt DEFAULT [] (Var f `mkVarApps` [z,z])]
   , ("go2 (in function call)",) $
      mkRFun go [x]
         (mkLetNonRec d (mkACase (Var go `mkVarApps` [x])
@@ -169,18 +170,19 @@ main = do
     runGhc (Just libdir) $ do
         getSessionDynFlags >>= setSessionDynFlags . flip gopt_set Opt_SuppressUniques
         dflags <- getSessionDynFlags
+        logger <- getLogger
         liftIO $ forM_ exprs $ \(n,e) -> do
             case lintExpr dflags [f,scrutf,scruta] e of
-                Just msg -> putMsg dflags (msg $$ text "in" <+> text n)
+                Just errs -> putMsg logger dflags (pprMessageBag errs $$ text "in" <+> text n)
                 Nothing -> return ()
-            putMsg dflags (text n Outputable.<> char ':')
+            putMsg logger dflags (text n Outputable.<> char ':')
             -- liftIO $ putMsg dflags (ppr e)
             let e' = callArityRHS e
             let bndrs = nonDetEltsUniqSet (allBoundIds e')
               -- It should be OK to use nonDetEltsUniqSet here, if it becomes a
               -- problem we should use DVarSet
             -- liftIO $ putMsg dflags (ppr e')
-            forM_ bndrs $ \v -> putMsg dflags $ nest 4 $ ppr v <+> ppr (idCallArity v)
+            forM_ bndrs $ \v -> putMsg logger dflags $ nest 4 $ ppr v <+> ppr (idCallArity v)
 
 -- Utilities
 mkLApps :: Id -> [Integer] -> CoreExpr
@@ -215,7 +217,7 @@ allBoundIds (Let (Rec binds) body) =
 allBoundIds (App e1 e2) = allBoundIds e1 `unionVarSet` allBoundIds e2
 allBoundIds (Case scrut _ _ alts) =
     allBoundIds scrut `unionVarSet` unionVarSets
-        [ allBoundIds e | (_, _ , e) <- alts ]
+        [ allBoundIds e | Alt _ _ e <- alts ]
 allBoundIds (Lam _ e)  = allBoundIds e
 allBoundIds (Tick _ e) = allBoundIds e
 allBoundIds (Cast e _) = allBoundIds e
