@@ -5,7 +5,7 @@ module KindEqualities where
 
 import Data.Kind
 
-data TyRep1 :: * -> * where
+data TyRep1 :: Type -> Type where
   TyInt1 :: TyRep1 Int
   TyBool1 :: TyRep1 Bool
 
@@ -15,13 +15,13 @@ zero1 TyBool1 = False
 
 data Proxy (a :: k) = P
 
-data TyRep :: forall k. k -> * where
+data TyRep :: forall k. k -> Type where
   TyInt :: TyRep Int
   TyBool :: TyRep Bool
   TyMaybe :: TyRep Maybe
   TyApp :: TyRep a -> TyRep b -> TyRep (a b)
 
-zero :: forall (a :: *). TyRep a -> a
+zero :: forall (a :: Type). TyRep a -> a
 zero TyInt = 0
 zero TyBool = False
 zero (TyApp TyMaybe _) = Nothing
