@@ -4,4 +4,4 @@ module T11635 where
 
 import Data.Kind
 
-data X (a :: forall k. k -> * ) b = X
+data X (a :: forall k. k -> Type) b = X
