@@ -40,6 +40,8 @@ expectedGhcOnlyExtensions =
     [ "RelaxedLayout"
     , "AlternativeLayoutRule"
     , "AlternativeLayoutRuleTransitional"
+    , "OverloadedRecordUpdate"
+    , "DeepSubsumption"
     ]
 
 expectedCabalOnlyExtensions :: [String]
@@ -53,4 +55,7 @@ expectedCabalOnlyExtensions = ["Generics",
                                "SafeImports",
                                "Safe",
                                "Unsafe",
-                               "Trustworthy"]
+                               "Trustworthy",
+                               "MonadFailDesugaring",
+                               "MonoPatBinds"
+                              ]
