@@ -1,5 +1,6 @@
 import System.Environment
 import GHC.Driver.Session
+import GHC.Driver.Config
 import GHC.Data.FastString
 import GHC
 import GHC.Data.StringBuffer
@@ -16,7 +17,8 @@ main = do
 
     hdk_comments <- runGhc (Just libdir) $ do
         dflags <- getSessionDynFlags
-        let pstate = mkPState (dflags `gopt_set` Opt_Haddock) stringBuffer loc
+        let opts   = initParserOpts (dflags `gopt_set` Opt_Haddock)
+            pstate = initParserState opts stringBuffer loc
         case unP (lexer False return) pstate of
             POk s (L _ ITeof) -> return (map unLoc (toList (hdk_comments s)))
             _                 -> error "No token"
