@@ -41,6 +41,6 @@ main = do
         | (MG _ (L _ (m:_)) _) <- fun_matches f,
           ((L _ (c@ConPat{})):_)<-hsLMatchPats m,
           (L l _)<-pat_con c
-        = isGoodSrcSpan l       -- Check that the source location is a good one
+        = isGoodSrcSpan (locA l) -- Check that the source location is a good one
       isDataCon _
         = False
