@@ -3,18 +3,18 @@ module Main where
 import GHC
 import GHC.Unit.State
 import GHC.Driver.Monad
-import GHC.Utils.Outputable
-import System.Environment
 import GHC.Driver.Session
+import GHC.Driver.Env
+import GHC.Utils.Outputable
 import GHC.Unit.Module
+import System.Environment
 
 main =
   do [libdir] <- getArgs
      _ <- runGhc (Just libdir) $ do
                 dflags <- getSessionDynFlags
                 setSessionDynFlags dflags
-                dflags <- getSessionDynFlags
-                let state = unitState dflags
+                state <- hsc_units <$> getSession
                 liftIO $ print (mkModuleName "GHC.Utils.Outputable" `elem` listVisibleModuleNames state)
      _ <- runGhc (Just libdir) $ do
                 dflags <- getSessionDynFlags
@@ -23,7 +23,6 @@ main =
                                                   (PackageArg "ghc")
                                                   (ModRenaming True [])]
                     })
-                dflags <- getSessionDynFlags
-                let state = unitState dflags
+                state <- hsc_units <$> getSession
                 liftIO $ print (mkModuleName "GHC.Utils.Outputable" `elem` listVisibleModuleNames state)
      return ()
