@@ -8,6 +8,7 @@ import Data.List (intercalate)
 import System.IO
 import GHC
 import GHC.Driver.Session
+import GHC.Driver.Ppr
 import GHC.Utils.Monad
 import GHC.Utils.Outputable
 import GHC.Data.Bag (filterBag,isEmptyBag)
@@ -40,4 +41,4 @@ showToks ts = intercalate ",\n\n"
             $ map (\((L p t),s) ->
                          "(" ++ pp p ++ "," ++ show t ++ ",[" ++ s ++ "])") ts
 
-pp a = showPpr unsafeGlobalDynFlags a
+pp a = showPprUnsafe a
