@@ -11,6 +11,7 @@ module Main where
 
 import GHC
 import GHC.Driver.Session
+import GHC.Driver.Backend
 import GHC.Utils.Monad ( MonadIO(..) )
 import GHC.Types.Basic ( failed )
 import GHC.Data.Bag        ( bagToList )
@@ -22,10 +23,11 @@ main = do
   libdir : args <- getArgs
   runGhc (Just libdir) $ do
     dflags0 <- getSessionDynFlags
-    (dflags, _, _) <- parseDynamicFlags dflags0
+    logger <- getLogger
+    (dflags, _, _) <- parseDynamicFlags logger dflags0
       (map (mkGeneralLocated "on the commandline") args)
-    setSessionDynFlags $ dflags { hscTarget = HscNothing
-                                , ghcLink  = LinkInMemory
+    setSessionDynFlags $ dflags { backend   = NoBackend
+                                , ghcLink   = LinkInMemory
                                 , verbosity = 0 -- silence please
                                 }
     root_mod <- guessTarget "A.hs" Nothing
@@ -35,7 +37,7 @@ main = do
     prn "target nothing: ok"
 
     dflags <- getSessionDynFlags
-    setSessionDynFlags $ dflags { hscTarget = HscInterpreted }
+    setSessionDynFlags $ dflags { backend = Interpreter }
     ok <- load LoadAllTargets
     when (failed ok) $ error "Couldn't load A.hs in interpreted mode"
     prn "target interpreted: ok"
