@@ -1,22 +1,25 @@
 {-# OPTIONS_GHC -Wall #-}
 module Hooks.Plugin (plugin) where
 
-import GHC.Types.Basic
+import GHC.Types.SourceText
 import GHC.Plugins
 import GHC.Hs.Expr
+import Language.Haskell.Syntax.Extension
 import GHC.Hs.Extension
 import GHC.Hs.Lit
 import GHC.Driver.Hooks
 import GHC.Tc.Utils.Monad
+import GHC.Parser.Annotation
 
 plugin :: Plugin
-plugin = defaultPlugin { dynflagsPlugin = hooksP }
+plugin = defaultPlugin { driverPlugin = hooksP }
 
-hooksP :: [CommandLineOption] -> DynFlags -> IO DynFlags
-hooksP opts dflags = return $ dflags
-  { hooks = (hooks dflags)
-    { runMetaHook = Just (fakeRunMeta opts) }
-  }
+hooksP :: [CommandLineOption] -> HscEnv -> IO HscEnv
+hooksP opts hsc_env = do
+    let hooks  = hsc_hooks hsc_env
+        hooks' = hooks { runMetaHook = Just (fakeRunMeta opts) }
+        hsc_env' = hsc_env { hsc_hooks = hooks' }
+    return hsc_env'
 
 -- This meta hook doesn't actually care running code in splices,
 -- it just replaces any expression splice with the "0"
@@ -28,7 +31,7 @@ fakeRunMeta opts (MetaE r) _ = do
   pure $ r zero
 
   where zero :: LHsExpr GhcPs
-        zero = L noSrcSpan $ HsLit NoExtField $
+        zero = noLocA $ HsLit noAnn $
           HsInt NoExtField (mkIntegralLit (0 :: Int))
 
 fakeRunMeta _ _ _ = error "fakeRunMeta: unimplemented"
