@@ -1,7 +1,7 @@
 module Simple.TrustworthyPlugin (plugin) where
 
-import GhcPlugins
-import TcRnMonad
+import GHC.Plugins
+import GHC.Tc.Utils.Monad
 
 plugin :: Plugin
 plugin = defaultPlugin
