@@ -23,16 +23,18 @@ module Main where
 import qualified GHC.CmmToAsm.Reg.Graph.Stats as Color
 import qualified GHC.CmmToAsm.Reg.Linear.Base as Linear
 import qualified GHC.CmmToAsm.X86.Instr as X86.Instr
+import qualified GHC.CmmToAsm.X86 as X86
 import GHC.Driver.Main
+import GHC.Driver.Env
 import GHC.StgToCmm.CgUtils
 import GHC.CmmToAsm
 import GHC.CmmToAsm.Config
-import GHC.CmmToAsm.Monad as NCGConfig
 import GHC.Cmm.Info.Build
 import GHC.Cmm.Pipeline
 import GHC.Cmm.Parser
 import GHC.Cmm.Info
 import GHC.Cmm
+import GHC.Parser.Errors.Ppr
 import GHC.Unit.Module
 import GHC.Cmm.DebugBlock
 import GHC
@@ -40,9 +42,11 @@ import GHC.Driver.Monad
 import GHC.Types.Unique.FM
 import GHC.Types.Unique.Supply
 import GHC.Driver.Session
+import GHC.Driver.Errors
 import GHC.Utils.Error
 import GHC.Utils.Outputable
 import GHC.Types.Basic
+import GHC.Unit.Home
 
 import GHC.Data.Stream as Stream (collect, yield)
 
@@ -60,10 +64,14 @@ main = do
 
     --get a GHC context and run the tests
     runGhc (Just libdir) $ do
-        dflags <- fmap setOptions getDynFlags
+        dflags0 <- fmap setOptions getDynFlags
+        setSessionDynFlags dflags0
+
+        dflags <- getDynFlags
+        logger <- getLogger
         reifyGhc $ \_ -> do
             us <- unitTestUniqSupply
-            runTests dflags us
+            runTests logger dflags us
 
     return ()
 
@@ -97,6 +105,7 @@ assertIO = assertOr $ \msg -> void (throwIO . RegAllocTestException $ msg)
 -- ***NOTE*** This function sets Opt_D_dump_asm_stats in the passed
 -- DynFlags because it won't work without it.  Handle stderr appropriately.
 compileCmmForRegAllocStats ::
+    Logger ->
     DynFlags ->
     FilePath ->
     (NCGConfig ->
@@ -104,26 +113,29 @@ compileCmmForRegAllocStats ::
     UniqSupply ->
     IO [( Maybe [Color.RegAllocStats (Alignment, RawCmmStatics) X86.Instr.Instr]
         , Maybe [Linear.RegAllocStats])]
-compileCmmForRegAllocStats dflags' cmmFile ncgImplF us = do
-    let ncgImpl = ncgImplF (NCGConfig.initConfig dflags)
+compileCmmForRegAllocStats logger dflags' cmmFile ncgImplF us = do
+    let ncgImpl = ncgImplF (initNCGConfig dflags thisMod)
     hscEnv <- newHscEnv dflags
 
     -- parse the cmm file and output any warnings or errors
-    ((warningMsgs, errorMsgs), parsedCmm) <- parseCmmFile dflags cmmFile
+    let fake_mod = mkHomeModule (hsc_home_unit hscEnv) (mkModuleName "fake")
+    (warnings, errors, parsedCmm) <- parseCmmFile dflags fake_mod (hsc_home_unit hscEnv) cmmFile
+    let warningMsgs = fmap pprWarning warnings
+        errorMsgs   = fmap pprError errors
 
     -- print parser errors or warnings
-    mapM_ (printBagOfErrors dflags) [warningMsgs, errorMsgs]
+    mapM_ (printBagOfErrors logger dflags) [warningMsgs, errorMsgs]
 
     let initTopSRT = emptySRT thisMod
-    cmmGroup <- fmap snd $ cmmPipeline hscEnv initTopSRT $ fromJust parsedCmm
+    cmmGroup <- fmap snd $ cmmPipeline hscEnv initTopSRT $ fst $ fromJust parsedCmm
 
-    rawCmms <- cmmToRawCmm dflags (Stream.yield cmmGroup)
+    rawCmms <- cmmToRawCmm logger dflags (Stream.yield cmmGroup)
 
     collectedCmms <- mconcat <$> Stream.collect rawCmms
 
     -- compile and discard the generated code, returning regalloc stats
     mapM (\ (count, thisCmm) ->
-        cmmNativeGen dflags thisMod thisModLoc ncgImpl
+        cmmNativeGen logger dflags thisModLoc ncgImpl
             usb dwarfFileIds dbgMap thisCmm count >>=
                 (\(_, _, _, _, colorStats, linearStats, _) ->
                 -- scrub unneeded output from cmmNativeGen
@@ -155,8 +167,8 @@ noSpillsCmmFile = "no_spills.cmm"
 
 -- | Run each unit test in this file and notify the user of success or
 -- failure.
-runTests :: DynFlags -> UniqSupply -> IO ()
-runTests dflags us = testGraphNoSpills dflags noSpillsCmmFile us >>= \res ->
+runTests :: Logger -> DynFlags -> UniqSupply -> IO ()
+runTests logger dflags us = testGraphNoSpills logger dflags noSpillsCmmFile us >>= \res ->
                         if res then putStrLn "All tests passed."
                                else hPutStr stderr "testGraphNoSpills failed!"
 
@@ -172,10 +184,10 @@ runTests dflags us = testGraphNoSpills dflags noSpillsCmmFile us >>= \res ->
 -- the register allocator should be able to do everything
 -- (on x86) in the passed file without any spills or reloads.
 --
-testGraphNoSpills :: DynFlags -> FilePath -> UniqSupply -> IO Bool
-testGraphNoSpills dflags' path us = do
+testGraphNoSpills :: Logger -> DynFlags -> FilePath -> UniqSupply -> IO Bool
+testGraphNoSpills logger dflags' path us = do
         colorStats <- fst . concatTupledMaybes <$>
-                        compileCmmForRegAllocStats dflags path x86NcgImpl us
+                        compileCmmForRegAllocStats logger dflags path X86.ncgX86 us
 
         assertIO "testGraphNoSpills: color stats should not be empty"
                         $ not (null colorStats)
