@@ -2,8 +2,11 @@ module LinkerUnload (init) where
 
 import GHC
 import GHC.Unit.State
+import GHC.Driver.Env
 import GHC.Driver.Session
-import GHC.Runtime.Linker as Linker
+import GHC.Driver.Backend
+import GHC.Runtime.Interpreter
+import qualified GHC.Linker.Loader as Loader
 import System.Environment
 import GHC.Utils.Monad ( MonadIO(..) )
 
@@ -14,8 +17,8 @@ loadPackages = do
   [libdir] <- getArgs
   runGhc (Just libdir) $ do
     dflags <- getSessionDynFlags
-    let dflags' = dflags { hscTarget = HscNothing
-                         , ghcLink  = LinkInMemory }
+    let dflags' = dflags { backend = NoBackend
+                         , ghcLink = LinkInMemory }
     setSessionDynFlags dflags'
     hsc_env <- getSession
-    liftIO $ Linker.linkPackages hsc_env (preloadUnits (unitState dflags'))
+    liftIO $ Loader.loadPackages (hscInterp hsc_env) hsc_env (preloadUnits (hsc_units hsc_env))
